Module init

Module init 

Driver initialization helpers.

CUDA requires cuInit(0) before any other driver call. baracuda-driver will call it automatically on first use of crate::Device::get and friends, but you may also call init yourself (e.g. at process start-up) to fail fast when CUDA is unavailable.

Functions

init
Ensure cuInit(0) has been called. Idempotent and thread-safe.
version
Driver version exposed by the installed libcuda, e.g. CudaVersion::CUDA_12_6.