pub unsafe fn raw_attributes_batched(
attributes: &mut [i32],
data: &mut [*mut c_void],
ptr: CUdeviceptr,
) -> Result<()>Expand description
Batched pointer-attribute query. For each attribute in attributes
there must be a matching writable slot in data sized for that
attribute’s value type.
Safety
Each data[i] must point to a buffer large enough to receive
attributes[i]’s value type.